package com.redhat.thermostat.tools.eclipse.plugin.tests;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import org.eclipse.core.databinding.validation.IValidator;
import org.eclipse.core.runtime.IStatus;
import org.junit.Test;

import com.redhat.thermostat.tools.eclipse.plugin.Validators;

public class ValidatorsTest {

    @Test
    public void testNonEmptyStringRequiredFailsOnEmptyString() {
        IValidator validator = new Validators.NonEmptyStringRequired("");
        IStatus result = validator.validate("");
        assertFalse(result.isOK());
    }

    @Test
    public void testNonEmptyStringRequiredPassesOnNonEmptyString() {
        IValidator validator = new Validators.NonEmptyStringRequired("");
        IStatus result = validator.validate("foo");
        assertTrue(result.isOK());
    }

    @Test
    public void testPackageNameRequiredFailsOnEmptyString() {
        IValidator validator = new Validators.NonEmptyStringRequired("");
        IStatus result = validator.validate("");
        assertFalse(result.isOK());
    }

    @Test
    public void testPackageNameRequiredFailsOnSpaces() {
        IValidator validator = new Validators.PackageNameRequired();
        IStatus result = validator.validate("a b");
        assertFalse(result.isOK());
    }

    @Test
    public void testPackageNameRequiredPassesOnValidPackageName() {
        IValidator validator = new Validators.PackageNameRequired();
        IStatus result;

        result = validator.validate("a");
        assertTrue(result.isOK());

        result = validator.validate("a.b");
        assertTrue(result.isOK());

        result = validator.validate("a.b.c");
        assertTrue(result.isOK());
    }

    @Test
    public void testValidIdRequiredFailsOnEmptyGroupId() {
        IValidator validator = new Validators.ValidIdRequired("Group Id");
        IStatus result = validator.validate("");
        assertFalse(result.isOK());
    }

    @Test
    public void testValidIdRequiredPassesOnValidGroupId() {
        IValidator validator = new Validators.ValidIdRequired("Group Id");
        IStatus result;

        result = validator.validate("a");
        assertTrue(result.isOK());

        result = validator.validate("a-b");
        assertTrue(result.isOK());

        result = validator.validate("a-b-c");
        assertTrue(result.isOK());
    }

}
